Module encode

Module encode 

Base32 encoding routines

Functions

encode
Encode base32 using the default alphabet Returns a String result
encode_alphabet
Encode base32 using the specified Alphabet. Returns a String.
encode_alphabet_slice
Encode base32 using the specified Alphabet and the predefined output slice. Returns a usize of how many output bytes are filled.
encoded_len
Returns encoded length for given input length