pub fn encode_alphabet_slice<T: AsRef<[u8]>>(
input: T,
output_buf: &mut [u8],
alphabet: &Alphabet,
) -> usizeExpand description
Encode base32 using the specified Alphabet and the predefined output slice.
Returns a usize of how many output bytes are filled.